@@ -97,7 +97,7 @@ public:
     /**
      * Type of error logging we are using.
      */
-    typedef enum {NONE = 0, CONSOLE_LOG, USER_LOG, SYSTEM_LOG} logmode_t;
+    typedef enum {NONE = 0, CONSOLE_LOG, USER_LOG, SYSTEM_LOG, SECURITY_LOG} logmode_t;
 
     /**
      * Level of error logging.
@@ -112,7 +112,7 @@ public:
     /**
      * Main handler.
      */
-    typedef int (*mainproc_t)(int argc, char **argv);
+    typedef cpr_service_t   mainproc_t;
 
     /**
      * Exit handler.
@@ -715,12 +715,19 @@ public:
     static void debug(unsigned level, const char *format, ...) __PRINTF(2, 3);
 
     /**
-     * Print error message at specific error level.
+     * Print generic error message at specific error level.
      * @param level of error condition.
      * @param format string to use.
      */
     static void log(loglevel_t level, const char *format, ...) __PRINTF(2, 3);
 
+    /**
+     * Print security error message at specific error level.
+     * @param level of error condition.
+     * @param format string to use.
+     */
+    static void security(loglevel_t level, const char *format, ...) __PRINTF(2, 3);
+
     /**
      * Set logging level and state.
      * @param name of logging entity.
